@@ -17,7 +17,7 @@ CLI_CONFIG = {
         "help": "Hard stop the first time an error is raised",
     },
     "filter": {
-        "nargs": 1,
+        "type": str,
         "subcommands": ["describe"],
         "help": "A JMES search path",
     },
@@ -50,6 +50,10 @@ CLI_CONFIG = {
     "runtime": {
         "subcommands": ["state"],
     },
+    "reconciler": {
+        "options": ["-r", "-R"],
+        "subcommands": ["state"],
+    },
     "output": {
         "source": "rend",
         "subcommands": ["exec", "state", "describe", "decrypt"],
@@ -131,6 +135,10 @@ CONFIG = {
         "help": "The profile to use when when calling exec modules and states",
         "default": "default",
     },
+    "reconciler": {
+        "default": "none",
+        "help": "The reconciler plugin to use, 'none' by default",
+    },
 }
 SUBCOMMANDS = {
     "encrypt": {
@@ -162,4 +170,5 @@ DYNE = {
     "states": ["states"],
     "tool": ["tool"],
     "output": ["output"],
+    "reconcile": ["reconcile"],
 }
