@@ -3,6 +3,7 @@ from typing import Dict
 from typing import Iterable
 from typing import Tuple
 
+import aiofiles
 import pop.hub
 from dict_tools import data
 
@@ -16,6 +17,7 @@ async def run(
     kwargs: Dict[str, Any],
     acct_file: str = None,
     acct_key: str = None,
+    acct_blob: bytes = None,
     acct_profile: str = "default",
 ):
     args = [a for a in args]
@@ -31,7 +33,11 @@ async def run(
 
     if "ctx" in params:
         ctx = await hub.idem.ex.ctx(
-            path, acct_file=acct_file, acct_key=acct_key, acct_profile=acct_profile
+            path,
+            acct_file=acct_file,
+            acct_key=acct_key,
+            acct_profile=acct_profile,
+            acct_blob=acct_blob,
         )
         args.insert(0, ctx)
 
@@ -45,6 +51,7 @@ async def ctx_(
     acct_profile: str = "default",
     acct_file: str = None,
     acct_key: str = None,
+    acct_blob: bytes = None,
 ):
     """
     :param hub:
@@ -52,6 +59,7 @@ async def ctx_(
     :param acct_profile:
     :param acct_file:
     :param acct_key:
+    :param acct_blob:
     :return:
     """
     ctx = data.NamespaceDict()
@@ -64,8 +72,13 @@ async def ctx_(
 
     acct_paths = (f"exec.{sname}.ACCT", f"states.{sname}.ACCT")
 
-    if acct_file and acct_key:
-        await hub.acct.init.unlock(acct_file, acct_key)
+    acct_data = {}
+    if acct_key:
+        if acct_file:
+            async with aiofiles.open(acct_file, "rb") as fh:
+                acct_blob = await fh.read()
+        if acct_blob:
+            acct_data = await hub.acct.init.unlock_blob(acct_blob, acct_key=acct_key)
 
     subs = set()
     for name in acct_paths:
@@ -74,7 +87,11 @@ async def ctx_(
             if isinstance(sub, Iterable) and sub:
                 subs.update(set(sub))
 
-    ctx.acct = await hub.acct.init.gather(subs, acct_profile)
+    ctx.acct = await hub.acct.init.gather(
+        subs,
+        acct_profile,
+        profiles=acct_data.get("profiles"),
+    )
 
     return ctx
 
