@@ -79,6 +79,7 @@ async def introduce(hub, name, state, sls_ref, cfn):
         include = state.pop("include")
     else:
         include = []
+    hub.idem.resolve.meta(name, state, sls_ref)
     hub.idem.resolve.extend(name, state, sls_ref)
     hub.idem.resolve.exclude(name, state, sls_ref)
     hub.idem.resolve.decls(name, state, sls_ref)
@@ -154,6 +155,13 @@ def extend(hub, name, state, sls_ref):
         state.setdefault("__extend__", []).append(ext)
 
 
+def meta(hub, name, state, sls_ref):
+    if "META" not in state:
+        return
+    raw_meta = state.pop("META")
+    hub.idem.RUNS[name]["meta"][sls_ref] = raw_meta
+
+
 def exclude(hub, name, state, sls_ref):
     """
     Resolve any exclude statements
