@@ -142,7 +142,8 @@ async def run(hub, name, ctx, low, seq_comp, running, run_num):
         running[tag] = {
             "name": chunk["name"],
             "changes": {},
-            "comment": f'The named state {chunk["state"]} is not available',
+            "comment": f'Could not find function to enforce {chunk["state"]}.'
+            f"Please make sure that the corresponding plugin is loaded.",
             "result": False,
             "__run_num": run_num,
         }
