@@ -3,6 +3,7 @@ import json
 import uuid
 from typing import Any
 from typing import Dict
+from typing import List
 
 import aiofiles
 import dict_tools.update
@@ -24,22 +25,28 @@ class Status(enum.IntEnum):
 
 async def create(
     hub,
-    name,
-    sls_sources,
-    render,
-    runtime,
-    subs,
-    cache_dir,
-    test,
-    acct_file,
-    acct_key,
-    acct_profile,
+    name: str,
+    sls_sources: List[str],
+    render: str,
+    runtime: str,
+    subs: List[str],
+    cache_dir: str,
+    test: bool,
+    acct_file: str,
+    acct_key: str,
+    acct_profile: str,
+    acct_blob: bytes = None,
 ):
     """
     Create a new instance to execute against
     """
-    if acct_file and acct_key:
-        await hub.acct.init.unlock(acct_file, acct_key)
+    acct_data = {}
+    if acct_key:
+        if acct_file:
+            async with aiofiles.open(acct_file, "rb") as fh:
+                acct_blob = await fh.read()
+        if acct_blob:
+            acct_data = await hub.acct.init.unlock_blob(acct_blob, acct_key=acct_key)
 
     hub.idem.RUNS[name] = {
         "sls_sources": sls_sources,
@@ -58,26 +65,29 @@ async def create(
         "sls_refs": {},
         "blocks": {},
         "running": {},
+        "meta": {},
         "run_num": 1,
         "add_low": [],
         "acct_profile": acct_profile,
+        "acct_data": acct_data,
         "status": Status.CREATED,
     }
 
 
 async def apply(
     hub,
-    name,
-    sls_sources,
-    render,
-    runtime,
-    subs,
-    cache_dir,
-    sls,
-    test=False,
-    acct_file=None,
-    acct_key=None,
-    acct_profile="default",
+    name: str,
+    sls_sources: List[str],
+    render: str,
+    runtime: str,
+    subs: List[str],
+    cache_dir: str,
+    sls: List[str],
+    test: bool = False,
+    acct_file: str = None,
+    acct_key: str = None,
+    acct_profile: str = "default",
+    acct_blob: bytes = None,
 ):
     """
     Run idem!
@@ -90,9 +100,10 @@ async def apply(
         subs,
         cache_dir,
         test,
-        acct_file,
-        acct_key,
-        acct_profile,
+        acct_file=acct_file,
+        acct_key=acct_key,
+        acct_profile=acct_profile,
+        acct_blob=acct_blob,
     )
     # Get the sls file
     # render it
@@ -225,18 +236,17 @@ async def batch(
     if encrypted_profiles:
         if isinstance(encrypted_profiles, str):
             encrypted_profiles = encrypted_profiles.encode()
-        async with aiofiles.tempfile.NamedTemporaryFile("wb+") as fh:
-            await fh.write(encrypted_profiles)
-            await fh.flush()
-            await hub.idem.state.apply(acct_file=fh.name, **apply_kwargs)
+        await hub.idem.state.apply(acct_blob=encrypted_profiles, **apply_kwargs)
     else:
         # Default to the acct_file defined in the environment at runtime
         await hub.idem.state.apply(acct_file=hub.OPT.acct.acct_file, **apply_kwargs)
 
-    if hub.idem.RUNS[name]["errors"]:
-        return hub.idem.RUNS[name]["errors"]
+    run_data = hub.idem.RUNS.pop(name)
 
-    return hub.idem.RUNS[name]["running"]
+    if run_data["errors"]:
+        return run_data["errors"]
+
+    return run_data["running"]
 
 
 def status(hub, name: str) -> Dict[str, Any]:
