@@ -127,14 +127,9 @@ def format_call(
     if missing_args:
         used_args_count = len(ret["args"]) + len(args)
         args_count = used_args_count + len(missing_args)
-        # raise SaltInvocationError(
-        #    '{0} takes at least {1} argument{2} ({3} given)'.format(
-        #        fun.name,
-        #        args_count,
-        #        args_count > 1 and 's' or '',
-        #        used_args_count
-        #    )
-        # )
+        raise RuntimeError(
+            f"{fun.name} takes at least {args_count} arguments ({used_args_count} given)"
+        )
 
     ret["kwargs"].update(kwargs)
 
